@@ -2,18 +2,18 @@ test_that("sum", {
   skip_if_no_sympy()
   
   a <- c("x", "x^2")
-  b <- as_symbol(a)
+  b <- as_sym(a)
   expect_equal(as.character(sum(b)), "x^2 + x")
   
-  p <- as_symbol(paste0("p", 1:3))
-  y <- as_symbol(paste0("y", 1:3))
-  a <- as_symbol("a")
+  p <- as_sym(paste0("p", 1:3))
+  y <- as_sym(paste0("y", 1:3))
+  a <- as_sym("a")
   expect_equal(as.character(sum(a)), "a")
   l <- sum(y*log(p))
   expect_equal(as.character(l), "y1*log(p1) + y2*log(p2) + y3*log(p3)")
   
   A <- matrix(c("x", 0, 0, "2*x", "3*x**2", "-1"), 2, 3)
-  B <- as_symbol(A)
+  B <- as_sym(A)
   expect_equal(as.character(sum(B)), "3*x^2 + 3*x - 1")
 })
 
@@ -33,7 +33,7 @@ test_that("cbind/rbind", {
   
   
   a <- c("x", "x^2")
-  b <- as_symbol(a)
+  b <- as_sym(a)
   
   expect_equal(unname(cbind(a, a, a)), 
                as_character_matrix(cbind(b, b, b)))
